@@ -173,6 +173,9 @@ INTERNALERROR_DFWERROR = 'InternalError.DfwError'
 # sql错误。
 INTERNALERROR_EXESQLERROR = 'InternalError.ExeSqlError'
 
+# 执行http请求错误。
+INTERNALERROR_EXECHTTPREQUESTERROR = 'InternalError.ExecHttpRequestError'
+
 # sql执行失败。
 INTERNALERROR_EXECUTESQLERROR = 'InternalError.ExecuteSQLError'
 
